#!/usr/bin/env python
import logging
from pathlib import Path

import arrow
from dateutil.relativedelta import relativedelta
from edc_test_utils import DefaultTestSettings, func_main

app_name = "edc_navbar"
base_dir = Path(__file__).absolute().parent

project_settings = DefaultTestSettings(
    calling_file=__file__,
    BASE_DIR=base_dir,
    APP_NAME=app_name,
    SILENCED_SYSTEM_CHECKS=["sites.E101", "edc_navbar.E003"],
    ETC_DIR=str(base_dir / app_name / "tests" / "etc"),
    ADVERSE_EVENT_APP_LABEL="adverse_event_app",
    ADVERSE_EVENT_ADMIN_SITE="adverse_event_app_admin",
    EDC_PROTOCOL_STUDY_OPEN_DATETIME=arrow.utcnow().floor("hour") - relativedelta(years=2),
    EDC_PROTOCOL_STUDY_CLOSE_DATETIME=arrow.utcnow().ceil("hour") + relativedelta(years=2),
    EDC_NAVBAR_DEFAULT=app_name,
    EDC_AUTH_CODENAMES_WARN_ONLY=True,
    EDC_SITES_REGISTER_DEFAULT=True,
    INSTALLED_APPS=[
        "django.contrib.admin",
        "django.contrib.auth",
        "django.contrib.contenttypes",
        "django.contrib.sessions",
        "django.contrib.messages",
        "django.contrib.staticfiles",
        "django.contrib.sites",
        "multisite",
        "django_crypto_fields.apps.AppConfig",
        "django_revision.apps.AppConfig",
        "edc_action_item.apps.AppConfig",
        "edc_adverse_event.apps.AppConfig",
        "edc_appointment.apps.AppConfig",
        "edc_auth.apps.AppConfig",
        "edc_dashboard.apps.AppConfig",
        "edc_data_manager.apps.AppConfig",
        "edc_export.apps.AppConfig",
        "edc_facility.apps.AppConfig",
        "edc_form_runners.apps.AppConfig",
        "edc_lab.apps.AppConfig",
        "edc_list_data.apps.AppConfig",
        "edc_listboard.apps.AppConfig",
        "edc_metadata.apps.AppConfig",
        "edc_model_form.apps.AppConfig",
        "edc_navbar.apps.AppConfig",
        "edc_notification.apps.AppConfig",
        "edc_pharmacy.apps.AppConfig",
        "edc_randomization.apps.AppConfig",
        "edc_registration.apps.AppConfig",
        "edc_review_dashboard.apps.AppConfig",
        "edc_sites.apps.AppConfig",
        "edc_subject_dashboard.apps.AppConfig",
        "edc_timepoint.apps.AppConfig",
        "edc_visit_schedule.apps.AppConfig",
        "edc_visit_tracking.apps.AppConfig",
        "adverse_event_app.apps.AppConfig",
        "edc_appconfig.apps.AppConfig",
    ],
    add_dashboard_middleware=True,
    use_test_urls=True,
).settings


def main():
    func_main(project_settings, *[f"{app_name}.tests"])


if __name__ == "__main__":
    logging.basicConfig()
    main()



from django.contrib.auth import get_user_model
from django.test import TestCase
from django.test.client import RequestFactory
from django.urls.base import reverse
from edc_dashboard import url_names

from ...navbar import Navbar
from ...navbar_item import NavbarItem
from ...site_navbars import AlreadyRegistered, site_navbars

User = get_user_model()


class TestNavbar(TestCase):
    @classmethod
    def setUpClass(cls):
        url_names.register("dashboard_url", "dashboard_url", "edc_dashboard")
        return super().setUpClass()

    def setUp(self):
        site_navbars._registry = {}
        self.user = User.objects.create_superuser("user_login", "u@example.com", "pass")
        rf = RequestFactory()
        self.request = rf.request()
        self.request.user = self.user

    def create_navbar(self) -> Navbar:
        testnavbar = Navbar(name="pharmacy_dashboard")
        testnavbar.register(
            NavbarItem(
                name="navbar1",
                title="Navbar1",
                label="one",
                codename="edc_navbar.navbar1",
                url_name="navbar_one_url",
            )
        )

        testnavbar.register(
            NavbarItem(
                name="navbar2",
                title="Navbar2",
                label="two",
                codename="edc_navbar.navbar2",
                url_name="navbar_two_url",
            )
        )
        return testnavbar

    def test_urls(self):
        reverse("navbar_one_url")
        reverse("navbar_two_url")

    def test_site_navbar_register(self):
        navbar = self.create_navbar()
        site_navbars.register(navbar)
        self.assertTrue(navbar.name in site_navbars.registry)
        self.assertRaises(AlreadyRegistered, site_navbars.register, navbar)

    def test_navbar_item_ok(self):
        navbar_item = NavbarItem(
            name="navbar_item_one",
            label="Navbar Item One",
            title="navbar_item_one",
            url_name="navbar_one_url",
            codename="edc_navbar.nav_one",
        )
        self.assertEqual(navbar_item.name, "navbar_item_one")
        self.assertEqual(navbar_item.title, "navbar_item_one")
        self.assertEqual(navbar_item.label, "Navbar Item One")

    def test_navbar_set_active(self):
        navbar = self.create_navbar()
        navbar.set_active("navbar2")
        self.assertTrue(navbar.get("navbar2").active)
        self.assertFalse(navbar.get("navbar1").active)
        navbar.set_active("navbar1")
        self.assertFalse(navbar.get("navbar2").active)
        self.assertTrue(navbar.get("navbar1").active)

    def test_navbar_urls(self):
        navbar = self.create_navbar()
        for navbar_item in navbar.navbar_items:
            self.assertIsNotNone(navbar_item.get_url())

    def test_navbar_disabled(self):
        navbar = self.create_navbar()
        for navbar_item in navbar.navbar_items:
            navbar_item.set_disabled(self.user)
            self.assertEqual(navbar_item.disabled, "")



from edc_model.models import BaseUuidModel, HistoricalRecords


class SubjectConsent(BaseUuidModel):
    history = HistoricalRecords()

    class Meta:
        pass


class SubjectReconsent(BaseUuidModel):
    history = HistoricalRecords()

    class Meta:
        pass


class SubjectVisit(BaseUuidModel):
    history = HistoricalRecords()

    class Meta:
        pass


class SubjectRequisition(BaseUuidModel):
    history = HistoricalRecords()

    class Meta:
        pass



from edc_auth.constants import EVERYONE
from edc_auth.site_auths import site_auths
from edc_auth.utils import remove_default_model_permissions_from_edc_permissions

from .auth_objects import custom_codename_tuples

site_auths.add_post_update_func(
    "edc_navbar", remove_default_model_permissions_from_edc_permissions
)
site_auths.add_custom_permissions_tuples(
    model="edc_navbar.edcpermissions", codename_tuples=custom_codename_tuples
)

site_auths.update_group(
    "edc_navbar.nav_administration",
    "edc_navbar.nav_home",
    "edc_navbar.nav_logout",
    "edc_navbar.nav_public",
    name=EVERYONE,
)



from django.urls import include, path
from django.views.generic.base import RedirectView, View
from edc_utils.paths_for_urlpatterns import paths_for_urlpatterns

urlpatterns = []

for app_name in [
    "edc_auth",
    "edc_data_manager",
    "edc_pharmacy",
    "edc_lab",
    "edc_locator",
    "edc_device",
    "edc_adverse_event",
    "edc_visit_schedule",
    "edc_navbar",
    "edc_consent",
    "edc_protocol",
    "edc_dashboard",
    "edc_export",
]:
    for p in paths_for_urlpatterns(app_name):
        urlpatterns.append(p)

urlpatterns += [
    path("i18n/", include("django.conf.urls.i18n")),
    path(r"", View.as_view(), name="navbar_one_url"),
    path(r"", View.as_view(), name="navbar_two_url"),
    path("", RedirectView.as_view(url="admin/"), name="administration_url"),
    path("", RedirectView.as_view(url="admin/"), name="home_url"),
    path("", RedirectView.as_view(url="admin/"), name="logout"),
]
